@@ -1,20 +1,13 @@
 use super::*;
 
-/// Returns the build's `.windows` directory in the root of the workspace as a `PathBuf`.
-pub fn workspace_windows_dir() -> std::path::PathBuf {
-    let mut path = workspace_dir();
-    path.push(".windows");
-    path
-}
-
-pub fn workspace_winmds() -> &'static [File] {
+pub fn crate_winmds() -> &'static [File] {
     use std::{mem::MaybeUninit, sync::Once};
     static ONCE: Once = Once::new();
     static mut VALUE: MaybeUninit<Vec<File>> = MaybeUninit::uninit();
 
     ONCE.call_once(|| {
         // This is safe because `Once` provides thread-safe one-time initialization
-        unsafe { VALUE = MaybeUninit::new(get_workspace_winmds()) }
+        unsafe { VALUE = MaybeUninit::new(get_crate_winmds()) }
     });
 
     // This is safe because `call_once` has already been called.
@@ -60,39 +53,48 @@ pub fn workspace_dir() -> std::path::PathBuf {
     unsafe { (*VALUE.as_ptr()).clone() }
 }
 
-fn get_workspace_winmds() -> Vec<File> {
-    let mut windows_path = workspace_windows_dir();
-    windows_path.push("winmd");
-
-    let mut result = vec![];
-
-    if let Ok(files) = std::fs::read_dir(windows_path) {
-        for file in files.filter_map(|file| file.ok()) {
-            if let Ok(file_type) = file.file_type() {
-                if file_type.is_file() {
-                    let path = file.path();
-                    if let Some("winmd") = path.extension().and_then(|extension| extension.to_str())
-                    {
-                        result.push(File::new(path));
+fn get_crate_winmds() -> Vec<File> {
+    fn push_dir(result: &mut Vec<File>, dir: &std::path::PathBuf) {
+        if let Ok(files) = std::fs::read_dir(&dir) {
+            for file in files.filter_map(|file| file.ok()) {
+                if let Ok(file_type) = file.file_type() {
+                    if file_type.is_file() {
+                        let path = file.path();
+                        if let Some("winmd") =
+                            path.extension().and_then(|extension| extension.to_str())
+                        {
+                            result.push(File::new(path));
+                        }
                     }
                 }
             }
         }
     }
 
-    // TODO: include_bytes is very slow - it takes an extra 60ms compared with memory mapped files.
-    // https://github.com/rust-lang/rust/issues/65818
+    let mut result = vec![];
 
-    if !result.iter().any(|file| file.name.starts_with("Windows.")) {
-        result.push(File::from_bytes(
-            "Windows.Win32.winmd".to_string(),
-            include_bytes!("../default/Windows.Win32.winmd").to_vec(),
-        ));
-        result.push(File::from_bytes(
-            "Windows.WinRT.winmd".to_string(),
-            include_bytes!("../default/Windows.WinRT.winmd").to_vec(),
-        ));
-    }
+    let mut dir: std::path::PathBuf = std::env::var("CARGO_MANIFEST_DIR")
+        .expect("No `CARGO_MANIFEST_DIR` env variable set")
+        .into();
+
+    dir.push(".windows");
+    dir.push("winmd");
+    push_dir(&mut result, &dir);
+
+    let dir = std::env::var("PATH").expect("No `PATH` env variable set");
+    let end = dir.find(';').expect("Path not ending in `;`");
+    let mut dir: std::path::PathBuf = dir[..end].into();
+    dir.pop();
+    dir.pop();
+    dir.push(".windows");
+    dir.push("winmd");
+    push_dir(&mut result, &dir);
+
+    let mut dir = workspace_dir();
+    dir.push("target");
+    dir.push(".windows");
+    dir.push("winmd");
+    push_dir(&mut result, &dir);
 
     result
 }
